@@ -118,7 +118,7 @@ class Index:
                highlights=None, device: Optional[str] = None, filter_string: str = None,
                show_highlights=True, reranker=None, image_download_headers: Optional[Dict] = None,
                attributes_to_retrieve: Optional[List[str]] = None, boost: Optional[Dict[str,List[Union[float, int]]]] = None,
-               context: Optional[dict] = None, score_modifiers: Optional[dict] = None,
+               context: Optional[dict] = None, score_modifiers: Optional[dict] = None, model_auth: Optional[dict] = None
                ) -> Dict[str, Any]:
         """Search the index.
 
@@ -145,6 +145,7 @@ class Index:
                 retrieved.
             context: a dictionary to allow you to bring your own vectors and more into search.
             score_modifiers: a dictionary to modify the score based on field values, for tensor search only
+            model_auth: authorisation that lets Marqo download a private model, if required
         Returns:
             Dictionary with hits and other metadata
         """
@@ -180,6 +181,8 @@ class Index:
             body["context"] = context
         if score_modifiers is not None:
             body["scoreModifiers"] = score_modifiers
+        if model_auth is not None:
+            body["modelAuth"] = model_auth
         res = self.http.post(
             path=path_with_query_str,
             body=body
@@ -246,6 +249,7 @@ class Index:
         use_existing_tensors: bool = False,
         image_download_headers: dict = None,
         mappings: dict = None,
+        model_auth: dict = None
     ) -> Union[Dict[str, Any], List[Dict[str, Any]]]:
         """Add documents to this index. Does a partial update on existing documents,
         based on their ID. Adds unseen documents to the index.
@@ -269,7 +273,7 @@ class Index:
             image_download_headers: a dictionary of headers to be passed while downloading images,
                 for URLs found in documents
             mappings: a dictionary to help handle the object fields. e.g., multimodal_combination field
-
+            model_auth: used to authorise a private model
         Returns:
             Response body outlining indexing result
         """
@@ -281,7 +285,8 @@ class Index:
             update_method="replace",
             documents=documents, auto_refresh=auto_refresh, server_batch_size=server_batch_size,
             client_batch_size=client_batch_size, processes=processes, device=device, non_tensor_fields=non_tensor_fields,
-            use_existing_tensors=use_existing_tensors, image_download_headers=image_download_headers, mappings = mappings
+            use_existing_tensors=use_existing_tensors, image_download_headers=image_download_headers, mappings=mappings,
+            model_auth=model_auth
         )
 
     def update_documents(
@@ -342,9 +347,12 @@ class Index:
         non_tensor_fields: List = None,
         use_existing_tensors: bool = False,
         image_download_headers: dict = None,
-        mappings:dict = None
+        mappings: dict = None,
+        model_auth: dict = None
     ) -> Union[Dict[str, Any], List[Dict[str, Any]]]:
 
+        error_detected_message = ('Errors detected in add documents call. '
+                                  'Please examine the returned result object for more information.')
         if non_tensor_fields is None:
             non_tensor_fields = []
 
@@ -358,6 +366,7 @@ class Index:
         non_tensor_fields_query_param = utils.convert_list_to_query_params("non_tensor_fields", non_tensor_fields)
         image_download_headers_param = (utils.convert_dict_to_url_params(image_download_headers)
                                         if image_download_headers else '')
+        model_auth_param = (utils.convert_dict_to_url_params(model_auth) if model_auth else '')
         mappings_param = (utils.convert_dict_to_url_params(mappings) if mappings else '')
         query_str_params = (
             f"{f'&device={utils.translate_device_string_for_url(selected_device)}'}"
@@ -367,6 +376,7 @@ class Index:
             f"{f'&{non_tensor_fields_query_param}' if len(non_tensor_fields) > 0 else ''}"
             f"{f'&image_download_headers={image_download_headers_param}' if image_download_headers else ''}"
             f"{f'&mappings={mappings_param}' if mappings else ''}"
+            f"{f'&model_auth={model_auth_param}' if model_auth_param else ''}"
         )
         end_time_client_process = timer()
         total_client_process_time = end_time_client_process - start_time_client_process
@@ -404,7 +414,7 @@ class Index:
 
             mq_logger.debug(f"add_documents roundtrip: took {(total_client_request_time):.3f}s to send {num_docs} "
                             f"docs to Marqo (roundtrip, unbatched), for an average of {(total_client_request_time / num_docs):.3f}s per doc.")
-
+            errors_detected = False
             if server_batch_size is not None:
                 # with Server Batching (show processing time for each batch)
                 mq_logger.debug(f"add_documents Marqo index (server-side batch reports): ")
@@ -419,6 +429,8 @@ class Index:
                             mq_logger.debug(f"       marqo server batch {batch}: "
                                             f"processed {server_batch_result_count} docs in {(res[process][batch]['processingTimeMs'] / 1000):.3f}s, "
                                             f"for an average of {(res[process][batch]['processingTimeMs'] / (1000 * server_batch_result_count)):.3f}s per doc.")
+                            if 'errors' in res[process][batch] and res[process][batch]['errors']:
+                                errors_detected = True
                 else:
                     # for single process, timing messages should be arranged by batch ONLY
                     for batch in range(len(res)):
@@ -426,12 +438,18 @@ class Index:
                         mq_logger.debug(f"   marqo server batch {batch}: "
                                         f"processed {server_batch_result_count} docs in {(res[batch]['processingTimeMs'] / 1000):.3f}s, "
                                         f"for an average of {(res[batch]['processingTimeMs'] / (1000 * server_batch_result_count)):.3f}s per doc.")
+                        if 'errors' in res[batch] and res[batch]['errors']:
+                            errors_detected = True
             else:
                 # no Server Batching
                 if 'processingTimeMs' in res:       # Only outputs log if response is non-empty
                     mq_logger.debug(f"add_documents Marqo index: took {(res['processingTimeMs'] / 1000):.3f}s for Marqo to process & index {num_docs} "
                                     f"docs (server unbatched), for an average of {(res['processingTimeMs'] / (1000 * num_docs)):.3f}s per doc.")
+                if 'errors' in res and res['errors']:
+                    mq_logger.info(error_detected_message)
 
+            if errors_detected:
+                mq_logger.info(error_detected_message)
         total_add_docs_time = timer() - t0
         mq_logger.debug(f"add_documents completed. total time taken: {(total_add_docs_time):.3f}s.")
         return res
@@ -492,9 +510,10 @@ class Index:
         path_with_query_str = f"{base_path}?refresh=false{query_str_params}"
 
         mq_logger.debug(f"starting batch ingestion with batch size {batch_size}")
+        error_detected_message = ('Errors detected in add documents call. '
+                                  'Please examine the returned result object for more information.')
 
         deeper = ((doc, i, batch_size) for i, doc in enumerate(docs))
-
         def batch_requests(gathered, doc_tuple):
             doc, i, the_batch_size = doc_tuple
             if i % the_batch_size == 0:
@@ -506,6 +525,8 @@ class Index:
         batched = functools.reduce(lambda x, y: batch_requests(x, y), deeper, [])
 
         def verbosely_add_docs(i, docs):
+            errors_detected = False
+
             t0 = timer()
             if update_method == 'replace':
                 res = self.http.post(path=path_with_query_str, body=docs)
@@ -520,7 +541,7 @@ class Index:
             if isinstance(res, list):
                 # with Server Batching (show processing time for each batch)
                 mq_logger.info(
-                    f"   add_documents batch {i} roundtrip: took {(total_batch_time):.3f}s to add {num_docs} docs, "
+                    f"    add_documents batch {i} roundtrip: took {(total_batch_time):.3f}s to add {num_docs} docs, "
                     f"for an average of {(total_batch_time / num_docs):.3f}s per doc.")
 
                 if isinstance(res[0], list):
@@ -533,6 +554,9 @@ class Index:
                             mq_logger.debug(f"           marqo server batch {batch}: "
                                             f"processed {server_batch_result_count} docs in {(res[process][batch]['processingTimeMs'] / 1000):.3f}s, "
                                             f"for an average of {(res[process][batch]['processingTimeMs'] / (1000 * server_batch_result_count)):.3f}s per doc.")
+                            if 'errors' in res[process][batch] and res[process][batch]['errors']:
+                                errors_detected = True
+
                 else:
                     # for single process, timing messages should be arranged by batch ONLY
                     for batch in range(len(res)):
@@ -540,15 +564,20 @@ class Index:
                         mq_logger.debug(f"       marqo server batch {batch}: "
                                         f"processed {server_batch_result_count} docs in {(res[batch]['processingTimeMs'] / 1000):.3f}s, "
                                         f"for an average of {(res[batch]['processingTimeMs'] / (1000 * server_batch_result_count)):.3f}s per doc.")
+                        if 'errors' in res[batch] and res[batch]['errors']:
+                            errors_detected = True
             else:
                 # no Server Batching
                 if 'processingTimeMs' in res:       # Only outputs log if response is non-empty
                     mq_logger.info(
-                        f"   add_documents batch {i}: took {(res['processingTimeMs'] / 1000):.3f}s for Marqo to process & index {num_docs} "
+                        f"    add_documents batch {i}: took {(res['processingTimeMs'] / 1000):.3f}s for Marqo to process & index {num_docs} "
                         f"docs (server unbatched), for an average of {(res['processingTimeMs'] / (1000 * num_docs)):.3f}s per doc."
                         f" Roundtrip time: {(total_batch_time):.3f}s")
+                    if 'errors' in res and res['errors']:
+                        errors_detected = True
 
-
+            if errors_detected:
+                mq_logger.info(f"    add_documents batch {i}: {error_detected_message}")
             if verbose:
                 mq_logger.info(f"results from indexing batch {i}: {res}")
             return res
