@@ -1,5 +1,5 @@
-__marqo_version__ = "0.0.17"
-__marqo_release_page__ = "https://github.com/marqo-ai/marqo/releases/tag/0.0.17"
+__marqo_version__ = "0.0.21"
+__marqo_release_page__ = f"https://github.com/marqo-ai/marqo/releases/tag/{__marqo_version__}"
 
 
 def supported_marqo_version() -> str:
